'use strict';

module.exports = {
  gulpRunner: require('./lib/gulp-runner'),
  eraseTime: require('./lib/erase-time'),
  eraseLapse: require('./lib/erase-lapse'),
  skipLines: require('./lib/skip-lines'),
  headLines: require('./lib/head-lines'),
};

