import callBind from 'call-bind';

import getPolyfill from 'object.getprototypeof/polyfill';

export default callBind(getPolyfill(), Object);

export { default as getPolyfill } from 'object.getprototypeof/polyfill';
export { default as implementation } from 'object.getprototypeof/implementation';
export { default as shim } from 'object.getprototypeof/shim';
